@@ -5,7 +5,7 @@ package MooX::AttributeFilter;
 use v5.10;
 use strictures 1;
 
-our $VERSION = '0.002000'; # TRIAL
+our $VERSION = '0.002001'; # TRIAL
 
 use Carp;
 use Scalar::Util qw<looks_like_number>;
@@ -157,7 +157,7 @@ MooX::AttributeFilter - Implements 'filter' option for Moo-class attributes
 
 =head1 VERSION
 
-version 0.002000
+version 0.002001
 
 =head1 SYNOPSIS
 
@@ -296,9 +296,11 @@ depending on the current environment. For example:
     }
 }
 
-=head1 CAVEATS
+=head2 Inflation to Moose
 
-* This module doesn't inflate into Moose.
+This module inflates into L<MooseX::AttributeFilter>.
+
+=head1 CAVEATS
 
 * The code relies on low-level functionality of Method::Generate family of
   modules. For this reason it may become incompatible with their future versions 
@@ -312,6 +314,10 @@ itself is badly wanted there was no other choice but to create the module... So,
 my great thanks to Graham Knopp <haarg@haarg.org> for his advises, sample code,
 and Moo itself, of course!
 
+My special thanks to Princess Kitten <littleprincess@kittymail.com> who
+implemented similar module for Moose framework and made the inflation code
+working.
+
 =head1 AUTHOR
 
 Vadim Belman <vrurg@cpan.org>
